/*
 * This file is part of INAV Project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU General Public License Version 3, as described below:
 *
 * This file is free software: you may copy, redistribute and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This file is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */

#include <stdbool.h>
#include <platform.h>
#include "drivers/io.h"
#include "drivers/bus.h"
#include "drivers/timer.h"
#include "drivers/sensor.h"
#include "drivers/pwm_mapping.h"
#include "io/piniobox.h"
#include "fc/rc_modes.h"
/*
Betaflight
# timer
timer B04 AF2
# pin B04: TIM3 CH1 (AF2)
timer C08 AF3
# pin C08: TIM8 CH3 (AF3)
timer C09 AF3
# pin C09: TIM8 CH4 (AF3)
timer A08 AF1
# pin A08: TIM1 CH1 (AF1)
timer A09 AF1
# pin A09: TIM1 CH2 (AF1)
timer A10 AF1
# pin A10: TIM1 CH3 (AF1)
timer B03 AF1
# pin B03: TIM2 CH2 (AF1)

dma pin B04 NONE
dma pin C08 0  = DEF_TIM_AF__PC8__TCH_TIM8_CH3 = TIM8,  CH3, PC8
# pin C08: DMA2 Stream 2 Channel 0
dma pin C09 0  = DEF_TIM_AF__PC9__TCH_TIM8_CH4 = TIM8,  CH4, PC9
# pin C09: DMA2 Stream 7 Channel 7
dma pin A08 0  = DEF_TIM_AF__PA8__TCH_TIM1_CH1 = TIM1,  CH1, PA8
# pin A08: DMA2 Stream 6 Channel 0
dma pin A09 0  = DEF_TIM_AF__PA9__TCH_TIM1_CH2 = TIM1,  CH2, PA9
# pin A09: DMA2 Stream 6 Channel 0
dma pin A10 0  = DEF_TIM_AF__PA10__TCH_TIM1_CH3 = TIM1,  CH3, PA10
# pin A10: DMA2 Stream 6 Channel 0
dma pin B03 0  = DEF_TIM_AF__PB3__TCH_TIM2_CH2 = TIM2,  CH2, PB3
# pin B03: DMA1 Stream 6 Channel 3

resource MOTOR 1 C08
resource MOTOR 2 C09
resource MOTOR 3 A08
resource MOTOR 4 A09
resource LED_STRIP 1 B03
resource CAMERA_CONTROL 1 A10
*/
const timerHardware_t timerHardware[] = {
    DEF_TIM(TIM8,  CH3, PC8,  TIM_USE_MC_MOTOR | TIM_USE_FW_MOTOR,  0, 0),      // S1
    DEF_TIM(TIM8,  CH4, PC9,  TIM_USE_MC_MOTOR | TIM_USE_FW_MOTOR,  0, 0),      // S2
    DEF_TIM(TIM1,  CH1, PA8,  TIM_USE_MC_MOTOR | TIM_USE_FW_MOTOR,  0, 1),      // S3
    DEF_TIM(TIM1,  CH2, PA9,  TIM_USE_MC_MOTOR | TIM_USE_FW_MOTOR,  0, 1),      // S4
    //DEF_TIM(TIM1,  CH3, PA10,  TIM_USE_CAMERA_CONTROL,  0, 0),      // S5
    DEF_TIM(TIM2,  CH2, PB3,  TIM_USE_LED,  0, 0),      // S6
};

const int timerHardwareCount = sizeof(timerHardware) / sizeof(timerHardware[0]);

void targetConfiguration(void)
{
    pinioBoxConfigMutable()->permanentId[0] = BOXARM;
    pinioBoxConfigMutable()->permanentId[1] = BOXARM; // my own dvr 
}
